Learn R Programming

aroma.affymetrix (version 3.2.3)

getTags.TransformReport: Gets the tags of the output data set

Description

Gets the tags of the output data set, which equals the tags of the input data set plus the tags of this transformation.

Usage

# S3 method for TransformReport
getTags(this, collapse=NULL, ...)

Value

Returns a character

vector.

Arguments

...

Not used.

See Also

For more information see TransformReport.