powered by
Gets the tags of the output data set, which equals the tags of the input data set plus the tags of this transformation.
# S3 method for TransformReport getTags(this, collapse=NULL, ...)
Returns a character
character
vector.
vector
Not used.
For more information see TransformReport.
TransformReport